# Okrolearn 

Machine Learning library created by Okerew
<br>
To install do `pip install okrolearn==0.2.2`
<br>
To use in your code with the main module do `from okrolearn import okrolearn`
<br>
Then for example to use Tensor, do `okrolearn.Tensor()`
<br>
To add it to your directory, install requirements and then just import it by having it in your project directory
<br>
`from okrolearn.src.okrolearn import *`
<br>
You can also just download the okrolearn.py file and import it
<br>
`from okrolearn import *`
<br>
Note gpu and jit compilation are not yet supported.

